package com.bipt.intelligentapplicationorchestrationservice.entity;

import com.bipt.intelligentapplicationorchestrationservice.service.RedisCacheService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Objects;
import java.util.Set;
import java.util.stream.Collectors;

@Repository
public class GpuResourceRepository {
    // Redis键定义
    // Redis键模式定义
    private static final String GPU_KEY_PREFIX = "gpu:";

    private final RedisCacheService redisCacheService;

    @Autowired
    public GpuResourceRepository(RedisCacheService redisCacheService) {
        this.redisCacheService = redisCacheService;
    }

    /**
     * 保存或更新GPU资源
     * @param resource GPU资源对象
     */
    public void save(GpuResource resource) {
        redisCacheService.put(resource.getGPUId().toString(), resource);
    }

    /**
     * 按ID查询GPU资源
     * @param id GPU资源ID
     * @return GPU资源对象（可能为null）
     */
    public GpuResource findById(Long id) {
        return redisCacheService.get(id.toString());
    }

    /**
    public List<GpuResource> findByStatus(Status status) {
        // 由于Redis存储结构不支持直接按属性查询，需要通过keys + 过滤方式实现
        // 注意：生产环境中应考虑使用RedisSCAN替代KEYS（此处为简写）
        Set<String> keys = redisCacheService.scanKeys(GPU_KEY_PREFIX + "*");

        List<GpuResource> result = new ArrayList<>();
        keys.forEach(key -> {
            String gpuId = key.substring(GPU_KEY_PREFIX.length());
            GpuResource resource = redisCacheService.get(gpuId);
            if (resource != null && resource.getStatus() == status) {
                result.add(resource);
            }
        });

        return result;
    }

    public void updateStatus(Long gpuId, Status newStatus) {
        GpuResource resource = findById(gpuId);
        if (resource != null) {
            resource.setStatus(newStatus);
            save(resource);
        }
    }
    */
    public List<GpuResource> findAll() {
        Set<String> keys = redisCacheService.scanKeys("gpu:*");
        return keys.stream()
                .map(key -> {
                    String gpuId = key.substring(4); // 去除"gpu:"前缀
                    return redisCacheService.get(gpuId);
                })
                .filter(Objects::nonNull)
                .collect(Collectors.toList());
    }
}

