package com.bipt.intelligentapplicationorchestrationservice.entity;

import java.util.Objects;

public class ModelInfo {
    private String modelId;
    private String modelName;
    private String modelType;
    private String preprocessScript;
    private String modelFilePath;
    private String storageLocation;

    public String getModelId() {
        return modelId;
    }

    public void setModelId(String modelId) {
        this.modelId = modelId;
    }

    // Getter & Setter 方法
    public String getModelName() {
        return modelName;
    }

    public void setModelName(String modelName) {
        this.modelName = modelName;
    }

    public String getModelType() {
        return modelType;
    }

    public void setModelType(String modelType) {
        this.modelType = modelType;
    }

    public String getPreprocessScript() {
        return preprocessScript;
    }

    public void setPreprocessScript(String preprocessScript) {
        this.preprocessScript = preprocessScript;
    }

    public String getModelFilePath() {
        return modelFilePath;
    }

    public void setModelFilePath(String modelFilePath) {
        this.modelFilePath = modelFilePath;
    }

    public void setStorageLocation(String storageLocation) {
        // 验证路径格式
        if (storageLocation != null && !isValidStoragePath(storageLocation)) {
            throw new IllegalArgumentException("无效的存储路径: " + storageLocation);
        }
        this.storageLocation = storageLocation;
    }

    private boolean isValidStoragePath(String path) {
        // 1. 基本非空检查
        if (path == null || path.trim().isEmpty()) return false;

        // 2. 防止路径遍历攻击
        if (path.contains("..")) return false;

        // 3. 仅允许合法路径格式
        return path.startsWith("/") ||
                path.startsWith("s3://") ||
                path.matches("[a-zA-Z]:\\\\"); // Windows 路径
    }

    // Equals 和 HashCode 方法
    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ModelInfo modelInfo = (ModelInfo) o;
        return Objects.equals(modelName, modelInfo.modelName) &&
                Objects.equals(modelType, modelInfo.modelType) &&
                Objects.equals(preprocessScript, modelInfo.preprocessScript) &&
                Objects.equals(modelFilePath, modelInfo.modelFilePath);
    }

    @Override
    public int hashCode() {
        return Objects.hash(modelName, modelType, preprocessScript, modelFilePath);
    }

    // toString 方法
    @Override
    public String toString() {
        return "ModelInfo{" +
                "modelName='" + modelName + '\'' +
                ", modelType='" + modelType + '\'' +
                ", preprocessScript='" + preprocessScript + '\'' +
                ", modelFilePath='" + modelFilePath + '\'' +
                '}';
    }
}
