package com.bipt.intelligentapplicationorchestrationservice.service;

import com.bipt.intelligentapplicationorchestrationservice.entity.DeployRequest;
import com.bipt.intelligentapplicationorchestrationservice.entity.DeployResponse;
import com.bipt.intelligentapplicationorchestrationservice.entity.DeploymentResource;
import com.bipt.intelligentapplicationorchestrationservice.exception.EvaluationFailedException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
@Service
public class GrayDeployService {
    @Autowired
    private ModelEvaluator modelEvaluator;

    @Autowired
    private ResourceAllocator resourceAllocator;

    @Autowired
    private GpuResourceService gpuService;

//    @Autowired
//    private MQSender mqSender;

    public DeployResponse process(DeployRequest request) {
        // 检查评估状态
        if (!modelEvaluator.isEvaluationPassed(request.getModelId())) {
            throw new EvaluationFailedException("模型评估未通过");
        }

        // 分配资源并获取URL
        DeploymentResource resource = resourceAllocator.allocate(
                gpuService.getAvailableResources(),
                request.getRequiredMemory(),
                request.getModelId(),
                true
        );

//        // 发送MQ灰度通知
//        mqSender.sendGrayDeployNotification(
//                resource.getUrl(),
//                request.getModelId(),
//                resource.getGpu().getGPUId()
//        );
        // 标记资源已分配（更新内存使用量）
        gpuService.markAsAllocated(
                resource.getGpu().getGPUId(),
                request.getRequiredMemory()
        );
        return DeployResponse.success(resource.getUrl());

    }
}
