package com.bipt.intelligentapplicationorchestrationservice.util;

import com.bipt.intelligentapplicationorchestrationservice.entity.ModelInfo;
import org.springframework.stereotype.Service;

import java.text.MessageFormat;
import java.util.HashMap;
import java.util.Map;

@Service
public class TemplateParser {
    // 使用静态模板避免硬编码（可根据需要扩展为读取外部配置文件）
    private static final Map<String, String> DEPLOYMENT_TEMPLATES = new HashMap<>() {{
        put("tensorflow", "#!/bin/bash\n"
                + "# TensorFlow Serving Deployment\n"
                + "docker run -d --name {0}-service \\\n"
                + "  -p {1} \\\n"
                + "  -v {2}:/models/{0} \\\n"
                + "  -e MODEL_NAME={0} \\\n"
                + "  tensorflow/serving:latest\n"
                + "# Preprocessing\n"
                + "{3} $1");

        put("pytorch", "#!/bin/bash\n"
                + "# TorchServe Deployment\n"
                + "torch-model-archiver --model-name {0} \\\n"
                + "  --version 1.0 \\\n"
                + "  --serialized-file {2} \\\n"
                + "  --handler {3} \\\n"
                + "  --export-path model_store\n"
                + "torchserve --start \\\n"
                + "  --model-store model_store \\\n"
                + "  --models {0}.mar \\\n"
                + "  --ncs \\\n"
                + "  --ts-config config.properties");
    }};

    public String generateDeploymentScript(ModelInfo modelInfo, String endpointUrl) {
        // 提取URL端口号 (假设URL格式为 http://host:port)
        String port = extractPortFromUrl(endpointUrl);

        // 获取基础模板
        String template = DEPLOYMENT_TEMPLATES.getOrDefault(
                modelInfo.getModelType().toLowerCase(),
                getDefaultTemplate()
        );

        // 安全处理空值
        String safeModelName = modelInfo.getModelName() != null ? modelInfo.getModelName() : "unnamed";
        String safeFilePath = modelInfo.getModelFilePath() != null ? modelInfo.getModelFilePath() : "";
        String safeScript = modelInfo.getPreprocessScript() != null ? modelInfo.getPreprocessScript() : "echo 'No preprocessing'";

        // 填充模板参数
        return MessageFormat.format(template,
                safeModelName,
                port,
                safeFilePath,
                safeScript
        );
    }
    private String extractPortFromUrl(String url) {
        if (url == null) return "8080";  // 默认端口
        try {
            return url.split(":")[2].replaceAll("[^0-9]", "");
        } catch (Exception e) {
            return "8080";
        }
    }

    private String getDefaultTemplate() {
        return "#!/bin/bash\n"
                + "# Universal Deployment Template\n"
                + "echo \"Deploying model: {0} at endpoint {1}\"\n"
                + "echo \"Model path: {2}\"\n"
                + "echo \"Running preprocessing: {3}\"\n"
                + "# Add custom deployment logic here";
    }
}
